package com.ruoyi.supplier.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.supplier.domain.TCanteenRating;
import com.ruoyi.supplier.service.ITCanteenRatingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 评价Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/supplier/rating")
public class TCanteenRatingController extends BaseController
{
    @Autowired
    private ITCanteenRatingService tCanteenRatingService;

    /**
     * 查询评价列表
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenRating tCanteenRating)
    {
        startPage();
        List<TCanteenRating> list = tCanteenRatingService.selectTCanteenRatingList(tCanteenRating);
        return getDataTable(list);
    }

    /**
     * 导出评价列表
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:export')")
    @Log(title = "评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenRating tCanteenRating)
    {
        List<TCanteenRating> list = tCanteenRatingService.selectTCanteenRatingList(tCanteenRating);
        ExcelUtil<TCanteenRating> util = new ExcelUtil<TCanteenRating>(TCanteenRating.class);
        util.exportExcel(response, list, "评价数据");
    }

    /**
     * 获取评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:query')")
    @GetMapping(value = "/{rateId}")
    public AjaxResult getInfo(@PathVariable("rateId") Long rateId)
    {
        return success(tCanteenRatingService.selectTCanteenRatingByRateId(rateId));
    }

    /**
     * 新增评价
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:add')")
    @Log(title = "评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenRating tCanteenRating)
    {
        return toAjax(tCanteenRatingService.insertTCanteenRating(tCanteenRating));
    }

    /**
     * 修改评价
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:edit')")
    @Log(title = "评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenRating tCanteenRating)
    {
        return toAjax(tCanteenRatingService.updateTCanteenRating(tCanteenRating));
    }

    /**
     * 删除评价
     */
    @PreAuthorize("@ss.hasPermi('supplier:rating:remove')")
    @Log(title = "评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{rateIds}")
    public AjaxResult remove(@PathVariable Long[] rateIds)
    {
        return toAjax(tCanteenRatingService.deleteTCanteenRatingByRateIds(rateIds));
    }
}
